@@ -75,7 +75,7 @@ issue.time_stats()
 # end project issue time tracking stats
 
 # project issue set time estimate
-issue.set_time_estimate({'duration': '3h30m'})
+issue.time_estimate('3h30m')
 # end project issue set time estimate
 
 # project issue reset time estimate
@@ -83,11 +83,11 @@ issue.reset_time_estimate()
 # end project issue reset time estimate
 
 # project issue set time spent
-issue.add_time_spent({'duration': '3h30m'})
+issue.add_spent_time('3h30m')
 # end project issue set time spent
 
 # project issue reset time spent
-issue.reset_time_spent()
+issue.reset_spent_time()
 # end project issue reset time spent
 
 # project issue useragent
